describe Post do
	
	context "creating a draft" do

		it "should add a new blank file into the indicated repository" do
			Post.draft( ['helloworld'], {:site=>"rugpost", :markup=>"textile"} )
			File.exists?( DRAFT ).should be true
			# should raise exception if file already exists in source or output folder
		end

	end
	
	context "creating new post instance" do
		before(:all) do
			@post = Post.new( [DRAFT_NAME], {:site=>"rugpost"} )
		end

		it "should have metadata" do
			@post.metaops[:title].should == "Hello World"
			@post.metaops[:tags].should == ["Hello World", RuGPost::VERSION]
			@post.metaops[:gmail].should == "project"
		end

		it "should have body" do
			@post.src_body.should == "Hello from new *RuGPost* (#{RuGPost::VERSION}) user!"
		end

		it "should have html output" do
			@post.html_o.should == "<p>Hello from new <strong>RuGPost</strong> (#{RuGPost::VERSION}) user!</p>"
		end

		it "should write right subject from metadata" do
			@post.subject.should == "Hello World ((tags:Hello World,#{RuGPost::VERSION}))"
		end

	end

	context "sending mail" do
		it "should be able to send mail" do
			Mail.defaults do
				delivery_method :test
			end
			Mail::TestMailer.deliveries.length.should == 0
			email = Mail.deliver do
				to 'mikel@me.com'
				from 'you@you.com'
				subject 'testing'
				body 'hello'
			end
			email.body.should == 'hello'
			Mail::TestMailer.deliveries.length.should == 1
			Mail::TestMailer.deliveries.first.should equal email
			Mail::TestMailer.deliveries.clear
			Mail::TestMailer.deliveries.length.should == 0
		end
	end

	context "publishing a draft" do
		before(:all) do
			@post = Post.new( [DRAFT_NAME], {:site=>"rugpost"} )
		end

		it "should move html to published/output folder" do
			@post.move_html
			html = SAMPLE/'rugpost'/'published/output'/DRAFT_NAME + ".html"
			File.exists?(html).should be true
		end

		it "should move source to published/source" do
			@post.move_source
			File.exists?(SAMPLE/'rugpost'/'published/source'/DRAFT_NAME+'.'+DRAFT_MARKUP).should be true
		end

	end

end
